#include <iostream>
#include <array>
#include <algorithm>

struct Point64_t {
	int64_t r, c;
};

std::istream& operator >> (std::istream& is, Point64_t& p) noexcept {
	return is >> p.r >> p.c;
}

int64_t h, w, k;

const int64_t MAX_N_POint64_tS = 100'100;
std::array<Point64_t, MAX_N_POint64_tS> images;

void input_data() noexcept {
	std::ios_base::sync_with_stdio(false);
	std::cin.tie(nullptr);


	std::cin >> h >> w >> k;

	for (int64_t i = 0; i < k; ++i)
		std::cin >> images[i];
}

std::array<int64_t, MAX_N_POint64_tS> solve_indices;

template <typename Proj>
std::pair<int64_t, int64_t> solveFor(Proj&& proj, int64_t screen_size) noexcept {
	std::sort(solve_indices.begin(), solve_indices.begin() + k, [&proj](int64_t lhs, int64_t rhs) {
		return std::invoke(proj, images[lhs]) < std::invoke(proj, images[rhs]);
	});

	int64_t best_keys = 0, best_size = std::invoke(proj, images[solve_indices[k - 1]]) - std::invoke(proj, images[solve_indices[0]]) + 1;
	for (int64_t shift = 1; shift < k; ++shift) {
		int64_t pos1 = std::invoke(proj, images[solve_indices[shift - 1]]) + screen_size;
		int64_t pos2 = std::invoke(proj, images[solve_indices[shift]]);
		int64_t size = pos1 - pos2 + 1;

		int64_t distance = std::invoke(proj, images[solve_indices[shift - 1]]);
		int64_t keys = std::min(distance, screen_size - distance);

		if (size < best_size || size < best_size && keys < best_keys) {
			best_size = size;
			best_keys = keys;
		}
	}

	for (int64_t shift = 1; shift < k; ++shift) {
		int64_t pos1 = std::invoke(proj, images[solve_indices[shift]]) - screen_size;
		int64_t pos2 = std::invoke(proj, images[solve_indices[shift - 1]]);
		int64_t size = pos2 - pos1 + 1;

		int64_t distance = -pos1 + 1;
		int64_t keys = std::min(distance, screen_size - distance);

		if (size < best_size || size == best_size && keys < best_keys) {
			best_size = size;
			best_keys = keys;
		}
	}

	return { best_size, best_keys };
}

std::pair<int64_t, int64_t> solve() noexcept {
	for (int64_t i = 0; i < k; ++i)
		solve_indices[i] = i;

	auto [sizeR, keysR] = solveFor(&Point64_t::r, h);
	auto [sizeC, keysC] = solveFor(&Point64_t::c, w);

	return { sizeC * sizeR, keysR + keysC };
}

int main() {
	input_data();
	auto [size, keys] = solve();
	std::cout << size << ' ' << keys;
	return 0;
}
