#include <iostream>
#include <array>
#include <vector>
#include <algorithm>

const int MAX_N = 10'100;

int n;
std::array<int, MAX_N> data;

void input_data() noexcept {
	std::cin >> n;
	for (int i = 0; i < n; ++i) {
		std::cin >> data[i];
		--data[i];
	}
}

struct PrefixData {
	int records;
	int antirecords;
	int max;
	int min;
};

bool operator < (const PrefixData& lhs, const PrefixData& rhs) noexcept {
	return lhs.records + lhs.antirecords < rhs.records + rhs.antirecords;
}

PrefixData addToInc(PrefixData data, int value) noexcept {
	if (value > data.max) {
		++data.records;
		data.max = value;
	}
	return data;
}

PrefixData addToDec(PrefixData data, int value) noexcept {
	if (value < data.min) {
		++data.antirecords;
		data.min = value;
	}
	return data;
}

std::vector<PrefixData> currentPrefix;
std::vector<PrefixData> prevPrefix;

PrefixData& atNxN(std::vector<PrefixData>& prefix, int min, int max) noexcept {
	return prefix[min * n + max];
}

void spreadPrefixTo(int min, int max) noexcept {
	atNxN(currentPrefix, min, max) = atNxN(prevPrefix, min, max);
	if (min < n - 1)
		atNxN(currentPrefix, min, max) = std::max(atNxN(currentPrefix, min + 1, max), atNxN(currentPrefix, min, max));

	if (max > 0)
		atNxN(currentPrefix, min, max) = std::max(atNxN(currentPrefix, min, max - 1), atNxN(currentPrefix, min, max));
}

int solve() noexcept {
	currentPrefix.resize(n * n, { 0, 0, -1, n + 1 });
	prevPrefix.resize(n * n, { 0, 0, -1, n + 1 });				

	for (int i = 0; i < n; ++i) {
		swap(currentPrefix, prevPrefix);

		for (int min = n - 1; min >= 0; --min)
			for (int max = 0; max < n; ++max) {		
				spreadPrefixTo(min, max);

				if (data[i] == min)
					if (min == n -1)
						atNxN(currentPrefix, min, max) = std::max<PrefixData>({ 0, 1, -1, data[i] }, atNxN(currentPrefix, min, max));
					else
						atNxN(currentPrefix, min, max) = std::max(addToDec(atNxN(prevPrefix, min + 1, max), data[i]), 
																  atNxN(currentPrefix, min, max));
				if (data[i] == max)
					if (max == 0)
						atNxN(currentPrefix, min, max) = std::max<PrefixData>({ 1, 0, data[i], n + 1 }, atNxN(currentPrefix, min, max));
					else
						atNxN(currentPrefix, min, max) = std::max(addToInc(atNxN(prevPrefix, min, max - 1), data[i]),
																  atNxN(currentPrefix, min, max));
			}
	}

	int result = atNxN(currentPrefix, 0, n - 1).records + atNxN(currentPrefix, 0, n - 1).antirecords;

	currentPrefix.clear();
	prevPrefix.clear();

	return result;
}

int main() {
	std::ios_base::sync_with_stdio(false);
	std::cin.tie(nullptr);

	int t;
	std::cin >> t;
	for (int ti = 0; ti < t; ++ti) {
		input_data();
		std::cout << solve() << '\n';
	}
	return 0;
}
