#include <iostream>
#include <array>
#include <algorithm>

struct Activity {
	int64_t start;
	int64_t end;
};

int64_t n;
std::array<Activity, 200'100> activities;

std::array<int, 200'100> end_coords;

void input_data() noexcept {
	std::cin >> n;
	for (int64_t i = 0; i < n; ++i)
		std::cin >> activities[i].start >> activities[i].end;

	std::sort(activities.begin(), activities.begin() + n, [](Activity a1, Activity a2) {
		return a1.start < a2.start;
	});

	for (int i = 0; i < n; ++i) 
		end_coords[i] = activities[i].end;
	std::sort(end_coords.begin(), end_coords.begin() + n);
}

bool overlap(Activity a1, Activity a2) noexcept {
	return !(a1.end < a2.start || a2.end < a1.start);
}

int64_t mask_size(int64_t mask) noexcept {
	int64_t size = 0;
	for (int64_t i = 0; i < n; ++i)
		if (mask & (1ll << i))
			++size;
	return size;
}

bool is_compatable(int64_t mask) noexcept {
	for (int64_t i = 0; i < n; ++i)
		if (mask & (1ll << i))
			for (int64_t j = 0; j < n; ++j)
				if (i != j && (mask & (1ll << j)))
					if (overlap(activities[i], activities[j]))
						return false;
	return true;
}

std::array<std::array<int, 700 /* current */>, 700 /* rightmost */> compute_m_dp;

int64_t compute_m(int64_t selected = (1ll << n) - 1) noexcept {
	for (int r = 0; r < n; ++r)
		if ((selected & 1) && end_coords[r] >= activities[0].end)
			compute_m_dp[0][r] = 1;
		else
			compute_m_dp[0][r] = 0;

	for (int i = 1; i < n; ++i)
		for (int r = 0; r < n; ++r) {
			compute_m_dp[i][r] = compute_m_dp[i - 1][r];
			if ((selected & (1ll << i)) && end_coords[r] >= activities[i].end) {
				compute_m_dp[i][r] = std::max(compute_m_dp[i][r], 1);
				for (int r1 = 0; r1 < n; ++r1)
					if (end_coords[r1] < activities[i].start)
						compute_m_dp[i][r] = std::max(compute_m_dp[i - 1][r1] + 1, compute_m_dp[i][r]);
			}
		}

	int best = 0;
	for (int r = 0; r < n; ++r)
		best = std::max(compute_m_dp[n - 1][r], best);
	return best;
}

int64_t solve(int64_t m) noexcept {
	for (int64_t mask = 0; mask < (1ll << n); ++mask)
		if (mask_size(mask) == n / 2 && compute_m(mask) == m / 2)
			return mask;
	throw std::runtime_error{ "unreachable" };
}

void print_mask(int64_t mask) noexcept {
	bool outputed = false;
	for (int64_t i = 0; i < n; ++i)
		if (mask & (1ll << i)) {
			if (outputed)
				std::cout << ' ';
			else
				outputed = true;

			std::cout << i + 1;
		}
	std::cout << '\n';
}

int main() {
	std::ios_base::sync_with_stdio(false);
	std::cin.tie(nullptr);

	int64_t t;
	std::cin >> t;
	for (int64_t ti = 0; ti < t; ++ti) {
		input_data();
		print_mask(solve(compute_m()));
	}
}
