#include <iostream>
#include <array>

struct Activity {
	int64_t start;
	int64_t end;
};

int64_t n;
std::array<Activity, 200'100> activities;

void input_data() noexcept {
	std::cin >> n;
	for (int64_t i = 0; i < n; ++i)
		std::cin >> activities[i].start >> activities[i].end;
}

bool overlap(Activity a1, Activity a2) noexcept {
	return !(a1.end < a2.start || a2.end < a1.start);
}

int64_t mask_size(int64_t mask) noexcept {
	int64_t size = 0;
	for (int64_t i = 0; i < n; ++i)
		if (mask & (1ll << i))
			++size;
	return size;
}

// 0 for incompatable
int64_t compatable_size(int64_t mask) noexcept {
	int64_t size = 0;
	for (int64_t i = 0; i < n; ++i)
		if (mask & (1ll << i)) {
			++size;
			for (int64_t j = 0; j < n; ++j)
				if (mask & (1ll << j))
					if (overlap(activities[i], activities[j]))
						return 0;
		}
	return size;
}

int64_t compute_m() noexcept {
	int64_t m = 0;
	for (int64_t mask = 0; mask < (1ll << n); ++mask)
		for (int64_t i = 0; i < n; ++i)
			for (int64_t j = 0; j < n; ++j)
				m = std::max(compatable_size(mask), m);
	return m;
}

int64_t solve(int64_t m) noexcept {
	for (int64_t mask = 0; mask < (1ll << n); ++mask)
		if (mask_size(mask) == n / 2 && compatable_size(mask) == m / 2)
			return mask;
	throw std::runtime_error{ "unreachable" };
}

void print_mask(int64_t mask) noexcept {
	bool outputed = false;
	for (int64_t i = 0; i < n; ++i)
		if (mask & (1ll << i)) {
			if (outputed)
				std::cout << ' ';
			else
				outputed = true;

			std::cout << i + 1;
		}
	std::cout << '\n';
}

int main() {
	std::ios_base::sync_with_stdio(false);
	std::cin.tie(nullptr);

	int64_t t;
	std::cin >> t;
	for (int64_t ti = 0; ti < t; ++ti) {
		input_data();
		print_mask(solve(compute_m()));
	}
}
