#include <iostream>
#include <array>
#include <bitset>
#include <map>
#include <tuple>

int64_t n, q;
std::array<int64_t, 5100> weights;

void input_data() noexcept {
	std::cin >> n >> q;
	for (int64_t i = 0; i < n; ++i) {
		std::cin >> weights[i];
	}
}

std::array<std::bitset<5100>, 5100> is_accessable_table;
std::array<std::bitset<5100>, 5100> prev_is_accessable_table;

bool is_accessable(int a, int b) noexcept {
	if (a == 0 && b == 0) return true;
	if (a < 0 || b < 0) return false;
	return is_accessable_table[a][b];
}

bool prev_is_accessable(int a, int b) noexcept {
	if (a == 0 && b == 0) return true;
	if (a < 0 || b < 0) return false;
	return prev_is_accessable_table[a][b];
}

void precompute_is_accessable() noexcept {
	for (int i = 0; i < n; ++i) {
		prev_is_accessable_table = is_accessable_table;
		for (int a = 0; a < 5100; ++a)
			for (int b = 0; b < 5100; ++b)
				is_accessable_table[a][b] = prev_is_accessable(a - weights[i], b) || prev_is_accessable(a, b - weights[i]) || prev_is_accessable(a, b);
	}
}

std::array<std::bitset<5100>, 5100> is_ideal_table;
std::array<std::bitset<5100>, 5100> is_ideal_computed;

int64_t is_ideal(int64_t a, int64_t b) noexcept {
	if (a < 0 || b < 0) return false;
	if (a == 0 && b == 0) return true;

	if (is_ideal_computed[a][b])
		return is_ideal_table[a][b];

	is_ideal_computed[a][b] = true;
	return is_ideal_table[a][b] = is_accessable(a, b) && (a == 0 || is_ideal(a - 1, b)) && (b == 0 || is_ideal(a, b - 1));
}

bool solve(int64_t k, int64_t a, int64_t b) noexcept {
	return is_ideal(a, b);
}

void process_queries() noexcept {
	int64_t z;
	std::cin >> z;
	int64_t v = 0;
	for (int64_t qi = 0; qi < q; ++qi) {
		int64_t j, c, d;
		std::cin >> j >> c >> d;

		int64_t k = j - v * z, a = c - v * z, b = d - v * z;

		if (solve(k, a, b)) {
			++v;
			std::cout << "Yes\n";
		}
		else
			std::cout << "No\n";
	}
}

int main() {
	std::ios_base::sync_with_stdio(false);
	std::cin.tie(nullptr);

	input_data();
	precompute_is_accessable();

	process_queries();
}
