#include <iostream>
#include <iomanip>
#include <set>
#include <map>
#include <vector>
#include <algorithm>
#include <string>
#include <random>
#include <cmath>
#include <queue>

using namespace std;
typedef int ll;
typedef long double ld;
#define all(a) a.begin(), a.end()
void fastio() { ios_base::sync_with_stdio(0); cin.tie(0); cout.tie(0); }

const long long INF = 2e9;
const ll MOD = 1e9 + 7;
const ld EPS = 1e-9;

struct Segtree {
	struct Node {
		ll mx, mod;
		Node() : mx(-INF), mod(-1) {}
		Node(ll x) : mx(x), mod(-1) {}
		Node operator+(const Node& a) const {
			ll mx1 = mx;
			if (mod != -1) mx1 = mod;
			ll mx2 = a.mx;
			if (a.mod != -1) mx2 = a.mod;
			return Node(max(mx1, mx2));
		}
	};
	vector<Node> t;
	ll sz;
	Segtree() {}
	Segtree(vector<ll>& v) : sz(1) {
		ll n = v.size();
		while (sz < n)sz *= 2;
		t.resize(sz * 2, Node());
		for (ll i = 0; i < n; i++) t[sz + i] = Node(v[i]);
		for (ll i = sz - 1; i >= 1; i--) t[i] = t[i * 2] + t[i * 2 + 1];
	}
	void push(ll v) {
		if (v < sz && t[v].mod != -1) {
			t[v * 2].mod = t[v].mod;
			t[v * 2 + 1].mod = t[v].mod;
			t[v].mod = -1;
		}
	}
	void change(ll lx, ll rx, ll d, ll v = 1, ll l = 0, ll r = -1) {
		if (r == -1) r = sz;
		if (lx <= l && r <= rx) {
			t[v].mod = d;
			return;
		}
		if (l >= rx || lx >= r) return;
		push(v);
		ll m = (l + r) / 2;
		change(lx, rx, d, v * 2, l, m);
		change(lx, rx, d, v * 2 + 1, m, r);
		t[v] = t[v * 2] + t[v * 2 + 1];
	}
	Node get(ll lx, ll rx, ll v = 1, ll l = 0, ll r = -1) {
		if (r == -1) r = sz;
		if (lx <= l && r <= rx) return t[v] + Node();
		if (l >= rx || lx >= r) return Node();
		push(v);
		ll m = (l + r) / 2;
		Node res = Node();
		res = res + get(lx, rx, v * 2, l, m);
		res = res + get(lx, rx, v * 2 + 1, m, r);
		t[v] = t[v * 2] + t[v * 2 + 1];
		return res;
	}
};

int main() {
	fastio();
	ll t;
	cin >> t;
	while (t--) {
		ll n;
		cin >> n;
		vector<ll> a(n);
		for (ll i = 0; i < n; i++) cin >> a[i];
		vector<ll> dp(n + 1, INF);
		dp[0] = 0;
		for (ll i = 0; i < n; i++) {
			ll j = upper_bound(all(dp), a[i]) - dp.begin();
			dp[j] = a[i];
		}
		ll ans = 0;
		for (ll i = 0; i <= n; i++) {
			if (dp[i] < INF) ans = i;
		}
		if (ans >= n - 1) cout << n << "\n";
		else cout << ans + 2 << "\n";
	}
	return 0;
}