#include <bits/stdc++.h>

using namespace std;
using ll = long long;
constexpr int INF = numeric_limits<int>::max() / 2;
constexpr ll INFLL = numeric_limits<ll>::max() / 2;

template<class T>
istream &operator>>(istream &is, vector<T> &a) {
    for (auto &i : a) {
        is >> i;
    }
    return is;
}

struct SegTree {
    struct Node {
        int val = -1, push = -1;
    };

    vector<Node> tree;
    int n;

    SegTree(int n) : n(n) {
        tree.resize(4 * n);
    }

    void push(int v, int l, int r) {
        if (tree[v].push == -1) {
            return;
        }
        if (l + 1 < r) {
            tree[2 * v + 1].push = tree[v].push;
            tree[2 * v + 2].push = tree[v].push;
        }
        tree[v].val = tree[v].push;
        tree[v].push = -1;
    }

    void update(int v, int l, int r, int li, int ri, int x) {
        push(v, l, r);
        if (li >= r || l >= ri) {
            return;
        }
        if (li <= l && r <= ri) {
            tree[v].push = x;
            push(v, l, r);
            return;
        }
        int m = (l + r) / 2;
        update(2 * v + 1, l, m, li, ri, x);
        update(2 * v + 2, m, r, li, ri, x);
    }

    void update(int li, int ri, int x) {
        update(0, 0, n, li, ri, x);
    }

    int get(int v, int l, int r, int i) {
        push(v, l, r);
        if (l + 1 == r) {
            return tree[v].val;
        }
        int m = (l + r) / 2;
        if (i < m) {
            return get(2 * v + 1, l, m, i);
        } else {
            return get(2 * v + 2, m, r, i);
        }
    }

    int get(int i) {
        return get(0, 0, n, i);
    }
};

struct SegTree_2 {
    struct Node {
        int mx = -1, posmx = -1;
        int push = 0;
    };

    vector<Node> tree;
    int n;

    Node pull(const Node &a, const Node &b) {
        if (a.mx > b.mx) {
            return a;
        } else {
            return b;
        }
    }

    void build(int v, int l, int r, const vector<pair<int, int>> &a) {
        if (l + 1 == r) {
            tree[v].mx = a[l].first;
            tree[v].posmx = a[l].second;
            return;
        }
        int m = (l + r) / 2;
        build(2 * v + 1, l, m, a);
        build(2 * v + 2, m, r, a);
        tree[v] = pull(tree[2 * v + 1], tree[2 * v + 2]);
    }

    SegTree_2(vector<pair<int, int>> a) {
        n = a.size();
        tree.resize(4 * n);
    }

    void push(int v, int l, int r) {
        if (l + 1 < r) {
            tree[2 * v + 1].push += tree[v].push;
            tree[2 * v + 2].push += tree[v].push;
        }
        tree[v].mx += tree[v].push;
        tree[v].push = 0;
    }

    void update(int v, int l, int r, int li, int ri, int x) {
        push(v, l, r);
        if (li >= r || l >= ri) {
            return;
        }
        if (li <= l && r <= ri) {
            tree[v].push += x;
            push(v, l, r);
            return;
        }
        int m = (l + r) / 2;
        update(2 * v + 1, l, m, li, ri, x);
        update(2 * v + 2, m, r, li, ri, x);
        tree[v] = pull(tree[2 * v + 1], tree[2 * v + 2]);
    }

    void update(int li, int ri, int x) {
        update(0, 0, n, li, ri, x);
    }

    Node get(int v, int l, int r, int li, int ri) {
        push(v, l, r);
        if (li >= r || l >= ri) {
            return Node();
        }
        if (li <= l && r <= ri) {
            return tree[v];
        }
        int m = (l + r) / 2;
        return pull(get(2 * v + 1, l, m, li, ri), get(2 * v + 2, m, r, li, ri));
    }

    Node get(int li, int ri) {
        return get(0, 0, n, li, ri);
    }
};

mt19937 rng(228);

int main() {
    cin.tie(0)->sync_with_stdio(0);
#ifdef LOCAL
    freopen("input.txt", "r", stdin);
#endif
    int t;
    cin >> t;
    while (t--) {
        int n;
        cin >> n;
        vector<array<int, 3>> lr(n);
        vector<int> coords;
        for (int i = 0; i < n; ++i) {
            cin >> lr[i][0] >> lr[i][1];
            coords.push_back(lr[i][0]);
            coords.push_back(lr[i][1]);
            lr[i][2] = i;
        }
        sort(coords.begin(), coords.end());
        coords.resize(unique(coords.begin(), coords.end()) - coords.begin());
        for (auto &[l, r, _] : lr) {
            l = lower_bound(coords.begin(), coords.end(), l) - coords.begin();
            r = lower_bound(coords.begin(), coords.end(), r) - coords.begin();
        }
        sort(lr.begin(), lr.end(), [&](const array<int, 3> &a, const array<int, 3> &b) {
            return a[0] < b[0] || (a[0] == b[0] && a[1] > b[1]);
        });
        vector<int> par(n, -1);
        SegTree st(coords.size());
        for (int i = 0; i < n; ++i) {
            auto [l, r, _] = lr[i];
            par[i] = st.get(l);
//            assert(par[i] == st.get(r));
            st.update(l, r + 1, i);
        }
        vector<vector<int>> g(n);
        vector<int> roots;
        for (int i = 0; i < n; ++i) {
            if (par[i] != -1) {
                g[par[i]].push_back(i);
            } else {
                roots.push_back(i);
            }
        }
        vector<int> depth(n), tin(n), tout(n);
        vector<pair<int, int>> tour;
        auto dfs1 = [&](auto dfs1, int v) -> void {
            tour.push_back({depth[v], v});
            tin[v] = tour.size() - 1;
            for (auto u : g[v]) {
                depth[u] = depth[v] + 1;
                dfs1(dfs1, u);
            }
            tout[v] = tour.size();
        };
        for (int i : roots) {
            dfs1(dfs1, i);
        }
        vector<int> leaves;
        for (int i = 0; i < n; ++i) {
            if (g[i].empty()) {
                leaves.push_back(i);
            }
        }
        SegTree_2 govno(tour);
        vector<int> gg(n);
        int sz = min(n / 2, (int) leaves.size() / 2);
        vector<int> ggg;
        set<pair<int, int>> kok;
        for (int i = 0; i < n; ++i) {
            kok.insert({tin[i], i});
        }
        for (int i = 0; i < sz; ++i) {
            auto [mm, v, pp] = govno.get(0, n);
            ggg.push_back(v);
            while (1) {
                auto it = kok.upper_bound({tin[v], INF});
                if (it == kok.begin() || tout[prev(it)->second] < tin[v]) {
                    break;
                }
                --it;
                int u = it->second;
                govno.update(tin[u], tout[u], -1);
                kok.erase(it);
            }
        }
//        while (ggg.size() < sz) {
//            ggg.push_back(leaves[rng() % leaves.size()]);
//        }
        leaves = ggg;
//        int sz = leaves.size() / 2;
//        while (leaves.size() > sz) {
//            leaves.pop_back();
//        }
        for (int i : leaves) {
            gg[i] = 1;
        }
        auto dfs2 = [&](auto dfs2, int v) -> void {
            for (auto u : g[v]) {
                dfs2(dfs2, u);
                gg[v] += gg[u];
            }
        };
        for (int i : roots) {
            dfs2(dfs2, i);
        }
        vector<int> ver;
        auto dfs3 = [&](auto dfs3, int v) -> void {
            if (!g[v].empty()) {
                ver.push_back(v);
            }
            for (auto u : g[v]) {
                if (gg[u] > 0) {
                    dfs3(dfs3, u);
                }
            }
        };
        for (int i : roots) {
            if (gg[i] > 0) {
                dfs3(dfs3, i);
            }
        }
        sort(ver.begin(), ver.end(), [&](int a, int b) {
            return depth[a] > depth[b];
        });
//        assert(ver.size() + leaves.size() >= n / 2);
        while (!ver.empty() && leaves.size() + ver.size() > n / 2) {
            ver.pop_back();
        }
        for (int i : leaves) {
            cout << lr[i][2] + 1 << " ";
        }
        for (auto i : ver) {
            cout << lr[i][2] + 1 << " ";
        }
        cout << "\n";
//        auto solve = [&](int mask) {
//            vector<array<int, 3>> cur;
//            for (int i = 0; i < n; ++i) {
//                if ((mask >> i) & 1) {
//                    auto [l, r, _] = lr[i];
//                    for (auto [lj, rj, j] : cur) {
//                        int li = max(l, lj), ri = min(r, rj);
//                        if (li <= ri) {
//                            return 0;
//                        }
//                    }
//                    cur.push_back(lr[i]);
//                }
//            }
//            return 1;
//        };
//        vector<bool> okk(1 << n);
//        int m = 0;
//        for (int mask = 0; mask < (1 << n); ++mask) {
//            okk[mask] = solve(mask);
//            if (okk[mask]) {
//                m = max(m, __builtin_popcount(mask));
//            }
//        }
//        vector<int> bad, good;
//        for (int mask = 0; mask < (1 << n); ++mask) {
//            if (okk[mask]) {
//                int cnt = __builtin_popcount(mask);
//                if (cnt > m / 2) {
//                    bad.push_back(mask);
//                } else if (cnt == m / 2) {
//                    good.push_back(mask);
//                }
//            }
//        }
//        int ans = -1;
//        for (int mask = 0; mask < (1 << n); ++mask) {
//            if (__builtin_popcount(mask) != n / 2) {
//                continue;
//            }
//            int cur = 0;
//            for (int submask = mask;; submask = (submask - 1) & mask) {
//                if (okk[submask]) {
//                    cur = max(cur, __builtin_popcount(submask));
//                }
//                if (cur > m / 2) {
//                    break;
//                }
//                if (submask == 0) {
//                    break;
//                }
//            }
//            if (cur == m / 2) {
//                ans = mask;
//                break;
//            }
//        }
//        assert(ans != -1);
//        for (int i = 0; i < n; ++i) {
//            if ((ans >> i) & 1) {
//                cout << lr[i][2] + 1 << " ";
//            }
//        }
//        cout << "\n";
    }
}
