#include <iostream>
#include <string>
#include <map>
#include <algorithm>
#include <vector>
using namespace std;

int ans = 0;

inline void update(int& val, int newmax)
{
	val = max(val, newmax);
	ans = max(ans, newmax);
}

typedef pair<int, int> pii;
typedef vector<vector<pii>> dp_t;

void append(const pii& p, vector<pii>& dest)
{
	while (dest.size() && dest.back().first <= p.first && dest.back().second >= p.second)
		dest.pop_back();
	dest.push_back(p);
}

void optimize(vector<pii>& dest)
{
	int l = 0;
	for (int i = 1; i < dest.size(); i++)
	{
		while (l >= 0 && dest[l].second >= dest[i].second)
			l--;
		if (l < 0 || (dest[l].first != dest[i].first))
			dest[++l] = dest[i];
	}
	dest.resize(l + 1);
}

template<class T>
void ensuresize(vector<T>& dest, int size)
{
	size++;
	if (dest.size() < size)
		dest.resize(size);
}

int find_to_max(const vector<pii>& v, int num)
{
	int l = -1, r = (int)v.size();
	while (r - l > 1)
	{
		int avg = (l + r) >> 1;
		if (v[avg].second >= num)
			r = avg;
		else
			l = avg;
	}
	return l;
}

void recalc(dp_t& dp, int num)
{
	for (int i = dp.size() - 1; i >= 0; i--)
	{
		//int minindex = 1e9;
		bool changed = false;
		int p = lower_bound(dp[i].data(), dp[i].data() + dp[i].size(), pii{ num, (int)1e9 }) - dp[i].data();
		if (p != dp[i].size())
		{
			ensuresize(dp, i + 1);
			pii newpair(num, dp[i][p].second);
			auto place = upper_bound(dp[i + 1].begin(), dp[i + 1].end(), newpair);
			//minindex = min(minindex, place - dp[i + 1].begin());
			changed = true;
			dp[i + 1].insert(place, newpair);
			if (dp[i][p].second == -1e9)
			{
				auto iter = dp[i].begin() + p;
				while (iter != dp[i].end() && iter->second == -1e9)
					iter++;
				dp[i].erase(dp[i].begin() + p, iter);
			}
		}
		p = find_to_max(dp[i], num);
		if (p != -1)
		{
			ensuresize(dp, i + 1);
			pii newpair(dp[i][p].first, num);
			auto place = upper_bound(dp[i + 1].begin(), dp[i + 1].end(), newpair);
			//minindex = min(minindex, place - dp[i + 1].begin());
			changed = true;
			dp[i + 1].insert(place, newpair);
			if (dp[i][p].first == 1e9)
			{
				auto iter = dp[i].begin() + p;
				auto end = next(iter);
				while (iter != dp[i].begin() && prev(iter)->first == 1e9)
					iter--;
				dp[i].erase(iter, end);
			}
		}
		if (changed)
			optimize(dp[i + 1]);
	}
	dp[0].clear();
}

int solve(const vector<int>& v)
{
	dp_t dp;
	dp.push_back({ pii{1e9, -1e9} });
	for (int i : v)
		recalc(dp, i);
	return dp.size() - 1;
}

int dumb(const vector<int>& v)
{
	ans = 0;
	map<pair<int, int>, int> dp1, dp2;
	dp1[{1e9, -1e9}] = 0;
	for (int i : v)
	{
		for (auto& p : dp1)
		{
			auto& extr = p.first;
			if (extr.first > i)
				update(dp2[{i, extr.second}], p.second + 1);
			if (extr.second < i)
				update(dp2[{extr.first, i}], p.second + 1);
			if (extr.first < i || extr.second > i)
				update(dp2[extr], p.second);
		}
		dp1.swap(dp2);
		dp2.clear();
	}
	return ans;
}

void test(int n)
{
	vector<int> perm(n);
	for (int i = 0; i < n; i++)
		perm[i] = i + 1;
	while (true)
	{
		for (int i = 0; i < n - 1; i++)
			swap(perm[i], perm[i + rand() % (n - i)]);
		int ouf = solve(perm);
		int ans = dumb(perm);
		if (ouf != ans)
		{
			for (int i : perm)
				cout << i << ' ';
			cout << '\n' << ans << ' ' << ouf;
			return;
		}
	}
}

void mainprog()
{
	int t; cin >> t;
	for (; t; --t)
	{
		int n; cin >> n;
		vector<int> v(n);
		for (int& i : v)
			cin >> i;
		cout << solve(v) << '\n';
	}
}

int main()
{
	ios::sync_with_stdio(0);
	cin.tie(0);
	cout.tie(0);
	mainprog();
}