#include <iostream>
#include <string>
#include <vector>
#include <set>
#include <map>
#include <algorithm>
using namespace std;

typedef long long ll;
typedef pair<ll, ll> pii;
typedef pair<ll, ll> pll;

struct seg
{
	ll l, r;
	bool intersects(const seg& other) const
	{
		return other.r >= l || r >= other.l;
	}
	bool operator<(const seg& other) const
	{
		return make_pair(r, l) < make_pair(other.r, other.l);
	}
};

istream& operator>>(istream& in, seg& s)
{
	return in >> s.l >> s.r;
}

void calcdp(const vector<pair<seg, ll>>& v, vector<ll>& dp, vector<ll>& p)
{
	ll n = v.size();
	dp.resize(n); p.resize(n);
	vector<int> maxdp(n), maxdpi(n);
	for (ll i = 0; i < n; i++)
	{
		const seg& cur = v[i].first;
		ll l = -1, r = n;
		while (r - l > 1)
		{
			ll avg = (l + r) >> 1;
			if (v[avg].first.r < cur.l)
				l = avg;
			else
				r = avg;
		}
		if (l == -1)
			dp[i] = 1,
			p[i] = -1;
		else
			dp[i] = maxdp[l] + 1,
			p[i] = maxdpi[l];
		if (i == 0)
		{
			maxdp[i] = 1;
			maxdpi[i] = -1;
		}
		else
		{
			if (dp[i] < maxdp[i - 1])
			{
				maxdp[i] = maxdp[i - 1];
				maxdpi[i] = maxdpi[i - 1];
			}
			else
			{
				maxdp[i] = dp[i];
				maxdpi[i] = i;
			}
		}
	}
}

vector<pair<seg, ll>> tidy(const vector<seg>& v)
{
	ll n = v.size();
	vector<pair<seg, ll>> res(n);
	for (ll i = 0; i < n; i++)
		res[i].first = v[i],
		res[i].second = i;
	sort(res.data(), res.data() + n);
	return res;
}

vector<ll> solve(const vector<seg>& segs)
{
	ll n = segs.size();
	vector<pair<seg, ll>> v = tidy(segs);
	vector<ll> dp, p;
	calcdp(v, dp, p);
	ll im = -1, m = 0;
	for (ll i = n - 1; i >= 0; i--)
	{
		ll c = dp[i];
		if (c > m)
		{
			m = c;
			im = i;
		}
	}
	ll hm = m / 2;
	/*ll leftmost = -1;
	for (ll i = 0; i < n; i++)
		if (dp[i] > hm)
		{
			leftmost = i;
			break;
		}
	vector<ll> ans;
	ans.reserve(n / 2);
	if (leftmost <= n / 2)
	{
		for (ll i = 0; i < leftmost; i++)
			ans.push_back(v[i].second);
		if (ans.size() < n / 2)
		{
			vector<bool> important(n);
			{
				ll i = im;
				for (; i != -1; i = p[i])
					important[i] = true;
			}
			for (ll i = leftmost; ans.size() < n / 2; i++)
				if (!important[i])
					ans.push_back(v[i].second);
		}
	}
	else
	{
		for (ll i = leftmost; i < n; i++)
			ans.push_back(v[i].second);
		if (ans.size() < n / 2)
		{
			ll ihm;
			for (ihm = leftmost - 1; dp[ihm] != hm; ihm--);
			vector<bool> important(n);
			{
				ll i = ihm;
				for (; i != -1; i = p[i])
					important[i] = true;
			}
			for (ll i = 0; ans.size() < n / 2; i++)
				if (!important[i])
					ans.push_back(v[i].second);
		}
	}
	vector<ll> inv;
	inv.swap(ans);
	sort(inv.data(), inv.data() + inv.size());
	ll j = 0;
	for (ll i = 0; i < n; i++)
	{
		if (j < inv.size() && i == inv[j])
			j++;
		else
			ans.push_back(i);
	}*/
	vector<ll> ans;
	ans.reserve(n);
	for (ll i = 0; i < n; i++)
	{
		if (dp[i] <= hm)
			ans.push_back(i);
	}
	if (ans.size() < n / 2)
	{
		vector<ll> inv;
		inv.swap(ans);
		sort(inv.data(), inv.data() + inv.size());
		ll j = 0;
		for (ll i = 0; i < n; i++)
		{
			if (j < inv.size() && i == inv[j])
				j++;
			else
				ans.push_back(i);
		}
	}
	if (ans.size() > n / 2)
	{
		ll dpmx = 0, mxi = -1;
		for (ll i = 0; i < ans.size(); i++)
			if (dpmx < dp[ans[i]])
			{
				dpmx = dp[ans[i]];
				mxi = i;
			}
		vector<bool> important(n);
		for (ll i = ans[mxi]; i != -1; i = p[i])
			important[i] = true;
		for (ll i = ans.size() - 1; ans.size() > n / 2; i--)
		{
			if (!important[ans[i]])
			{
				ans[i] = ans.back();
				ans.pop_back();
			}
		}
	}
	for (ll& i : ans)
		i = v[i].second;
	return ans;
}

ll getm(const vector<seg>& segs)
{
	auto v = tidy(segs);
	vector<ll> dp, p;
	calcdp(v, dp, p);
	ll m = 0;
	for (ll i : dp)
		m = max(m, i);
	return m;
}

void printtest(ll tcase, const vector<seg>& segs, const vector<ll>& ouf)
{
	cout << tcase << '\n';
	for (const seg& s : segs)
		cout << s.l << ' ' << s.r << "; ";
	cout << endl;
	for (ll i : ouf)
		cout << i + 1 << ' ';
}

vector<seg> randgen()
{
	while (true)
	{
		ll n = rand() % 100000 * 2 + 2;
		vector<seg> segs(n);
		for (seg& s : segs)
		{
			s.l = (long long)rand() * rand() % (ll)1e9 + 1;
			s.r = (long long)rand() * rand() % (ll)1e9 + 1;
			if (s.r < s.l)
				swap(s.r, s.l);
			s.r += s.r == s.l;
		}
		ll m1 = getm(segs);
		if (m1 & 1)
			continue;
		return segs;
	}
}

bool testone(ll testcase, const vector<seg>& segs)
{
	ll n = segs.size();
	vector<ll> ouf = solve(segs);
	if (ouf.size() * 2 != n)
	{
		printtest(testcase, segs, ouf);
		return false;
	}
	vector<seg> rem;
	for (ll i : ouf)
		rem.push_back(segs[i]);
	ll m2 = getm(rem);
	ll m1 = getm(segs);
	if (m2 * 2 != m1)
	{
		printtest(testcase, segs, ouf);
		cout << '\n';
		cout << m1 << ' ' << m2;
		return false;
	}
	return true;
}

void test()
{
	for (ll testcase = 1; ; testcase++)
	{
		auto segs = randgen();
		if (!testone(testcase, segs))
			return;
	}
}

signed main()
{
	ios::sync_with_stdio(0);
	cin.tie(0);
	cout.tie(0);
	ll t; cin >> t;
	for (; t; --t)
	{
		ll n; cin >> n;
		vector<seg> segs(n);
		for (auto& i : segs)
			cin >> i;
		auto ans = solve(segs);
		for (ll i : ans)
			cout << i + 1 << ' ';
		cout << '\n';
	}
}