#include <iostream>
#include <set>
#include <random>

using namespace std;

const int MAXN = 2'00'000;

mt19937 rnd;

struct treap{
    int x, priority;
    int sz, fl;

    treap* l, *r;

    treap(int val) : x(val), priority(rnd()), sz(1), l(nullptr), r(nullptr), fl(0) {};

};

inline int getsz(treap* t){
    if (t == nullptr) return 0;
    return 1 + (t->l == nullptr ? 0 : t->l->sz) + (t->r == nullptr ? 0 : t->r->sz);
}
inline void push(treap* t){
    if (t == nullptr) return;
    t->sz = getsz(t->l) + getsz(t->r) + 1;
    t->x += t->fl;
    if (t->l) t->l->fl += t->fl;
    if (t->r) t->r->fl += t->fl;
    t->fl = 0;
}

inline treap* merge(treap* a, treap* b){
    push(a);
    push(b);
    if (a == nullptr) return b;
    if (b == nullptr) return a;
    if (a->priority > b->priority){
        a->r = merge(a->r, b);
        a->sz = getsz(a->l) + getsz(a->r) + 1;
        return a;
    }
    else{
        b->l = merge(a, b->l);
        b->sz = getsz(b->l) + getsz(b->r) + 1;
        return b;
    }
}
inline pair<treap*, treap*> split(treap* t, int k){
    push(t);
    if (t == nullptr) return {nullptr, nullptr};
    if (t->x <= k){
        auto res = split(t->r, k);
        t->r = res.first; push(t);
        res.first = t;
        return res;
    }
    else{
        auto res = split(t->l, k);
        t->l = res.second; push(t);
        res.second = t;
        return res;
    }
}

vector<int> pp;
inline void wl(treap*t){
    push(t);
    if (t == nullptr) return;
    pp.push_back(t->x);
    wl(t->l);
    wl(t->r);
}
int n, k, q;
int ans[MAXN];
treap* p[MAXN];
int l[MAXN], r[MAXN];
int spin[MAXN];

void dfs(int v, int z=0){
    if (l[v] != -1){
        dfs(l[v], z + (v == 0 ? 0 : spin[v]));
        dfs(r[v], z + (v == 0 ? 0 : 1 - spin[v]));
        if (v != 0 && spin[v] == 0){
            p[r[v]]->fl++;
        }
        if (v != 0 && spin[v] == 1){
            p[l[v]]->fl++;
        }
        pp.clear();
        if (getsz(p[l[v]]) < getsz(p[r[v]])){
            wl(p[l[v]]);
            p[v] = p[r[v]];
        }
        else{
            wl(p[r[v]]);
            p[v] = p[l[v]];
        }
        for (int i : pp){
            auto res = split(p[v], i);
            p[v] = merge(res.first, merge(new treap(i), res.second));
        }
        //p[v] = merge(p[l[v]], p[r[v]]);
        auto res = split(p[v], k - z);
        ans[v] =  getsz(res.first);
        p[v] = merge(res.first, res.second);
    }
    else{
        ans[v] = (z <= k);
        p[v] = merge(p[v], new treap(0));
    }
}

int main() {
    cin >> n >> k >> q;
    for (int i = 0; i < n; i ++){
        p[i] = nullptr;
    }
    for (int i = 0; i < n; i ++){
        int ti; cin >> ti;
        if (ti == 0){
            l[i] = r[i] = -1;
        }
        else{
            cin >> l[i] >> r[i]; l[i] --; r[i]--;
            spin[l[i]] = 0;
            spin[r[i]] = 1;
        }
    }
    dfs(0);
    for (int i = 0; i < q; i ++){
        int u; cin >> u; u--;
        cout << ans[u] << endl;
    }
}
