#include <iostream>
#include <vector>
#include <algorithm>
#include <cassert>
#include <set>
using namespace std;

const int MAXN = 1e5 + 123;

void sort_second(vector<pair<int, int>>& v) {
    for (auto& x : v)
        x = {x.second, x.first};
    sort(v.begin(), v.end());
    for (auto& x : v)
        x = {x.second, x.first};
}

vector<pair<int, int>> get_skeleton(vector<pair<int, int>>& a) {
    int x = 0;
    vector<pair<int, int>> ans;
    for (auto p : a) {
        if (x <= p.first) {
            ans.push_back(p);
            x = p.second;
        }
    }
    return ans;
}

vector<pair<int, int>> remove_half(vector<pair<int, int>> a) {
    sort_second(a);
    int n = a.size();
    int m = a.back().second + 1;
    vector<int> dp(m);
    int ai = 0;
    for (int x = 1; x < m; ++x) {
        dp[x] = dp[x - 1];
        while (ai < n && a[ai].second <= x) {
            dp[x] = max(dp[x], dp[a[ai].first] + 1);
            ++ai;
        }
    }
    if (dp.back() % 2)
        return {};
    int rmodd = 0;
    int rmeven = 0;
    for (auto p : a) {
        if (dp[p.second] - dp[p.first] != 1)
            continue;
        if (dp[p.second] % 2)
            ++rmodd;
        else
            ++rmeven;
    }
    vector<pair<int, int>> ans;
    for (auto p : a) {
        if (dp[p.second] - dp[p.first] != 1) {
            ans.push_back(p);
        } else if (bool(dp[p.second] % 2) == (rmodd > rmeven)) {
            ans.push_back(p);
        }
    }
    assert(get_skeleton(ans).size() * 2 == get_skeleton(a).size());
    return ans;
}

bool isin(vector<pair<int, int>>& a, pair<int, int> sg) {
    auto it = lower_bound(a.begin(), a.end(), sg);
    return it < a.end() && sg == *it;
}

void solve() {
    int n;
    cin >> n;
    vector<int> cpr;
    vector<pair<int, int>> sg(n);
    for (int i = 0; i < n; ++i) {
        cin >> sg[i].first >> sg[i].second;
        ++sg[i].second;
        cpr.push_back(sg[i].first);
        cpr.push_back(sg[i].second);
    }
    sort(cpr.begin(), cpr.end());
    cpr.resize(unique(cpr.begin(), cpr.end()) - cpr.begin());
    for (int i = 0; i < n; ++i) {
        sg[i].first = lower_bound(cpr.begin(), cpr.end(), sg[i].first) - cpr.begin();
        sg[i].second = lower_bound(cpr.begin(), cpr.end(), sg[i].second) - cpr.begin();
    }
    vector<pair<int, int>> hlf = remove_half(sg);
    vector<pair<int, int>> skeleton = get_skeleton(hlf);
    sort(skeleton.begin(), skeleton.end());
    multiset<pair<int, int>> ans;
    for (auto p : skeleton)
        ans.insert(p);
    for (auto p : hlf) {
        if (ans.size() * 2 < sg.size() && !isin(skeleton, p)) {
            ans.insert(p);
        }
    }
    
    // cout << "(" << ans.size() <<") ";
    
    for (int i = 0; i < n; ++i) {
        auto it = ans.find(sg[i]);
        if (it != ans.end()) {
            cout << i + 1 << ' ';
            ans.erase(it);
        }
    }
    cout << '\n';
}

signed main() {
    int t;
    cin >> t;
    while (t--) {
        solve();
    }
}
