#include <bits/stdc++.h>

using namespace std;
using ll = long long;

void ckmax(int &x, int y) {
    if (x < y) {
        x = y;
    }
}

constexpr int inf = 1e8;

struct SegTreeMax {
    vector<int> t;
    int sz;

    void init(int n) {
        sz = n;
        t.assign(sz << 1, -inf);
    }

    void modify(int x, int i) {
        for (ckmax(t[x += sz], i); x >>= 1; ) {
            t[x] = max(t[x << 1], t[x << 1 | 1]);
        }
    }

    int rangeMax(int l, int r) {
        int ans = 0;
        for (l += sz, r += sz; l < r; l >>= 1, r >>= 1) {
            if (l & 1) ckmax(ans, t[l++]);
            if (r & 1) ckmax(ans, t[--r]);
        }
        return ans;
    }
};

struct Info {
    int a = -inf, b = -inf, c = -inf, ab = -inf, bc = -inf, cb = -inf, ac = -inf, abc = -inf;
};

Info operator+(const Info &l, const Info &r) {
    Info res{};
    res.a = max(l.a, r.a), res.b = max(l.b, r.b), res.c = max(l.c, r.c);
    res.ab = max({l.ab, l.a + r.b, r.ab});
    res.bc = max({l.bc, l.b + r.c, r.bc});
    res.abc = max({l.abc, l.ab + r.c, l.a + r.bc, r.abc});

    res.cb = max({l.c + r.b, r.cb, l.cb});
    res.ac = max({l.a + r.c, l.ac, r.ac});
    res.abc = max({res.abc, l.ac + r.b, l.a + r.cb});
    return res;
}

struct SegmentTree {
    vector<Info> t;
    int sz = 1;

    void init(int n) {
        sz = 1 << __lg(n) + !!(n & (n - 1));
        t.assign(sz << 1, Info());
    }

    void modify(int x, int i, int type) {
        x += sz;
        (type == 0 ? t[x].a : type == 1 ? t[x].b : t[x].c) = i;

        for (; x >>= 1; ) {
            t[x] = t[x << 1] + t[x << 1 | 1];
        }
    }

    Info rangeQuery(int l, int r, int x, int lx, int rx) {
        if (l >= rx || lx >= r) {
            return {};
        }
        if (l <= lx && rx <= r) {
            return t[x];
        }

        int mid = lx + rx >> 1;
        return rangeQuery(l, r, x << 1, lx, mid) + rangeQuery(l, r, x << 1 | 1, mid, rx);
    }

    Info rangeQuery(int l, int r) {
        return rangeQuery(l, r, 1, 0, sz);
    }
};

int smart(vector<int> a) {
//    cout << "a: \n";

//    for (int x : a) cout << x << " ";
//    cout << endl;

    int n = a.size();

    vector<int> ord(n, -1);

    for (int i = 0; i < n; ++i) {
        assert(a[i] >= 0 && a[i] < n && ord[a[i]] == -1);
        ord[a[i]] = i;
    }


    vector<int> prefInc(n, -inf), prefDec(n, -inf), sufInc(n, -inf), sufDec(n, -inf);

    SegTreeMax stMaxPref, stMaxSuf;
    stMaxPref.init(n), stMaxSuf.init(n);

    for (int x = 0; x < n; ++x) {
        int i = ord[x];

        prefInc[i] = stMaxPref.rangeMax(0, i) + 1;
        sufDec[i] = stMaxSuf.rangeMax(i + 1, n) + 1;

        stMaxPref.modify(i, prefInc[i]);
        stMaxSuf.modify(i, sufDec[i]);
    }

    stMaxPref.init(n), stMaxSuf.init(n);

    for (int x = n - 1; x >= 0; --x) {
        int i = ord[x];

        prefDec[i] = stMaxPref.rangeMax(0, i) + 1;
        sufInc[i] = stMaxSuf.rangeMax(i + 1, n) + 1;

        stMaxPref.modify(i, prefDec[i]);
        stMaxSuf.modify(i, sufInc[i]);
    }

    SegmentTree st;
    st.init(n);

    for (int x = n - 1; x >= 0; --x) {
        int i = ord[x];
        st.modify(i, sufDec[i], 1);
    }

//    cout << "prefInc: \n";
//
//    for (int x : prefInc) cout << x << " ";
//    cout << endl;
//
//    cout << "sufInc: \n";
//
//    for (int x : sufInc) cout << x << " ";
//    cout << endl;
//
//    cout << "prefDec: \n";
//
//    for (int x : prefDec) cout << x << " ";
//    cout << endl;
//
//    cout << "sufDec: \n";
//
//    for (int x : sufDec) cout << x << " ";
//    cout << endl;

    int ans = 0;

    for (int x = n - 1; x >= 0; --x) {
        int i = ord[x];
        st.modify(i, -inf, 1);

        Info L = st.rangeQuery(0, i);
        Info R = st.rangeQuery(i + 1, n);

        int now = max({R.abc, L.a + R.bc, L.a + R.cb});

        ans = max(ans, prefInc[i] + now);

//        if (prefInc[i] + now == 7) {
//            cout << x << endl;
//        }

        st.modify(i, prefDec[i], 0);
        st.modify(i, sufInc[i], 2);
    }

//    cout << "ans: " << ans << endl;

    assert(ans >= 4 && ans <= n);

    return ans;
}

void solve() {
    int n;
    cin >> n;

    vector<int> a(n);

    for (int i = 0; i < n; ++i) {
        cin >> a[i];
    }

    vector<int> b;
    b.push_back(1);
    b.push_back(n + 3);

    for (int i = 0; i < n; ++i) {
        b.push_back(a[i] + 1);
    }

    b.push_back(0);
    b.push_back(n + 2);

    int ans = smart(b);
    ans -= 4;

    assert(ans >= 1 && ans <= n);

    cout << ans << '\n';

//    cout << endl;
}

int main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);

    int test = 1;
    cin >> test;

    while (test--) {
        solve();
    }

    return 0;
}
