#include <iostream>
#include <random>
#include <vector>
#include <algorithm>

using namespace std;

#define all(v) (v).begin(), (v).end()
#define rall(v) (v).rbegin(), (v).rend()

mt19937 rnd(228);

#define int long long

class Fenwick {
private:
	vector <int> data;

	int get(int r) {
		int ans = 0;
		for (; r >= 0; r = (r & (r + 1)) - 1) {
			ans += data[r];
		}
		return ans;
	}

public:
	Fenwick(int n) {
		data.assign(n, 0);
	}

	void update(int pos) {
		for (; pos < data.size(); pos |= pos + 1) {
			++data[pos];
		}
	}

	int get(int l, int r) {
		return get(r - 1) - get(l - 1);
	}
};

void solve1() {
	int n, k; cin >> n >> k;
	vector <int> v(k); for (auto& x : v) cin >> x;

	vector <int> ans;
	Fenwick tree(n + 1);
	for (auto x : v) tree.update(x);
	for (auto x : v) {
		int l = x, r = x + n;
		while (l + 1 != r) {
			int m = (l + r) / 2;
			int c = 0;
			if (m > n) {
				c = tree.get(x, n + 1) + tree.get(1, m + 1 - n);
			}
			else {
				c = tree.get(x, m + 1);
			}
			if (c == m + 1 - x) l = m;
			else r = m;
		}
		r = (r - 1 + 2 * n) % n + 1;
		tree.update(r);
		ans.push_back(r);
	}
	sort(all(ans));
	for (auto x : ans) cout << x << ' ';
}

void solve2() {
	int n, k; cin >> n >> k;
	vector <int> v(k); for (auto& x : v) cin >> x;

	vector <int> ans;
	Fenwick tree(n + 1);
	for (auto x : v) tree.update(n + 1 - x);
	for (auto x : v) {
		int l = n + 1 - x, r = n + 1 - (x - n);
		while (l + 1 != r) {
			int m = (l + r) / 2;
			int c = 0;
			if (m > n) {
				c = tree.get(n + 1 - x, n + 1) + tree.get(1, m + 1 - n);
			}
			else {
				c = tree.get(n + 1 - x, m + 1);
			}
			if (c == m + 1 - (n + 1 - x)) l = m;
			else r = m;
		}
		r = (r - 1 + 2 * n) % n + 1;
		tree.update(r);
		ans.push_back(n + 1 - r);
	}
	sort(all(ans));
	for (auto x : ans) cout << x << ' ';
}

int32_t main() {
	ios_base::sync_with_stdio(false);
	cin.tie(nullptr);

	int32_t a; cin >> a;
	int32_t t = 1;
	cin >> t;
	while (t--) {
		if (a == 1) solve1();
		else solve2();
		cout << '\n';
	}
}