//#pragma GCC optimize("O3")
//#pragma GCC target("avx,avx2")
#include <iostream>
#include <random>
#include <vector>
#include <algorithm>
#include <cassert>

using namespace std;

#define all(v) (v).begin(), (v).end()
#define rall(v) (v).rbegin(), (v).rend()

mt19937 rnd(228);

#define int long long

class Fenwick {
private:
	vector <int> data;

public:
	Fenwick(int n) {
		data.assign(n, 0);
	}

	int get(int r) {
		int ans = 0;
		for (--r; r >= 0; r = (r & (r + 1)) - 1) {
			ans = max(ans, data[r]);
		}
		return ans;
	}

	void update(int pos, int val) {
		for (; pos < data.size(); ++pos) {
			data[pos] = max(val, data[pos]);
		}
	}
};

void solve() {
	int n; cin >> n;
	vector <int> v(n);
	for (auto& x : v) {
		cin >> x;
		--x;
	}

	Fenwick tree1(n);
	Fenwick tree2(n);
	vector <vector <int>> up(n, vector <int>(n)), down(n, vector <int>(n));
	for (int i = n - 1; i >= 0; --i) {
		auto x = v[i];
		for (int j = 0; j < n; ++j) {
			down[i][j] = tree1.get(j);
			up[i][j] = tree2.get(n - 1 - j);
		}
		tree1.update(x, down[i][x] + 1);
		tree2.update(n - 1 - x, up[i][x] + 1);
	}

	int ans = 0;
	for (int i = -1; i < n; ++i) {
		vector <int> st1, st2;
		for (int j = 0; j < n; ++j) {
			if (v[j] <= i) {
				if (!st1.empty() && v[st1.back()] > v[j]) {
					ans = max(ans, (int)st1.size() + up[j][v[st1.back()]] + (int)st2.size() + down[j][v[j]] + 1);
				}

				while (!st1.empty() && v[st1.back()] > v[j]) st1.pop_back();
				st1.push_back(j);
			}
			else {
				if (!st2.empty() && v[st2.back()] < v[j]) {
					ans = max(ans, (int)st2.size() + down[j][v[st2.back()]] + (int)st1.size() + up[j][v[j]] + 1);
				}

				while (!st2.empty() && v[st2.back()] < v[j]) st2.pop_back();
				st2.push_back(j);
			}
		}
		ans = max(ans, (int)st1.size() + (int)st2.size());
	}
	if (ans > n) exit(1);

	cout << ans;
}

int32_t main() {
	ios_base::sync_with_stdio(false);
	cin.tie(nullptr);


	int32_t t = 1;
	cin >> t;
	while (t--) {
		solve();
		cout << '\n';
	}
}