#include <iostream>
#include <vector>
#include <random>
#include <algorithm>

using namespace std;

template <typename T>
struct FenwickTree {
    vector<T> tree;
    int sz;
    
    FenwickTree(int n) {
        tree.assign(n + 1, {0, -1});
        sz = n;
    }

    void _update(int i, const T &x) {
        for (; i <= sz; i += i & -i) {
            tree[i] = max(tree[i], x);
        }
    }

    void update(int i, const T &x) {
        _update(i + 1, x);
    }

    T get(int r) {
        T res = {0, -1};
        for (; r > 0; r -= r & -r) {
            res = max(res, tree[r]);
        }
        return res;
    }
};

random_device rd;
mt19937 twister(rd());

void solve() {
    int n; cin >> n;
    vector<int> as(n);
    for (int i = 0; i < n; i++) {
        cin >> as[i];
    }
    vector<int> idx_perm(n);
    iota(idx_perm.begin(), idx_perm.end(), 0);
    vector<int> inv_idx_perm(n);
    iota(inv_idx_perm.begin(), inv_idx_perm.end(), 0);
    int L;
    for (int iter = 0; iter < 30; iter++) {
        FenwickTree<pair<int, int>> tree(n + 1);
        vector<int> dp(n, 0), prev(n, -1);
        for (int i = 0; i < n; i++) {
            int a = as[i];
            auto tmp = tree.get(a);
            if (tmp.first + 1 > dp[i]) {
                dp[i] = tmp.first + 1;
                prev[i] = (tmp.second == -1 ? -1 : inv_idx_perm[tmp.second]);
            }
            tree.update(a, {tmp.first + 1, idx_perm[i]});
        }
        L = tree.get(n + 1).first;
        if (L == n) {
            cout << n << endl;
            return;
        }
        vector<bool> is_in_lcs(n);
        int cur = inv_idx_perm[tree.get(n + 1).second];
        while (cur != -1) {
            is_in_lcs[cur] = true;
            cur = prev[cur];
        }
        vector<int> not_in_lcs;
        for (int i = 0; i < n; i++) {
            if (not is_in_lcs[i]) {
                not_in_lcs.push_back(i);
            }
        }
        // cerr << "Not in LCS: " << endl;
        // for (int i : not_in_lcs) {
        //     cerr << i << ' ';
        // }
        // cerr << endl;
        int k = not_in_lcs.size();
        for (int i = 0; i < k - 1; i++) {
            if (as[not_in_lcs[i + 1]] < as[not_in_lcs[i]]) {
                cout << L + 2 << endl;
                return;
            }
        }
        shuffle(idx_perm.begin(), idx_perm.end(), twister);
        for (int i = 0; i < n; i++) {
            inv_idx_perm[idx_perm[i]] = i;
        }
    }
    cout << L + 1 << endl;
}

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    int t; cin >> t;
    while (t--) {
        solve();
    }
}
