#include <iostream>
#include <vector>
#include <algorithm>
#include <cassert>
#include <set>
  
using namespace std;
  
struct Segment {
    int l, r;
    explicit Segment() = default;
    Segment(int l_, int r_) : l(l_), r(r_) {
  
    }
    const bool contains(const Segment &other) const {
        return l <= other.l && other.r <= r && (l != other.l || r != other.r);
    }
  
    const bool operator==(const Segment &other) const {
        return l == other.l && r == other.r;
    }
};
  
struct Event {
    int coord, type, index;
    explicit Event() = default;
    Event(int coord_, int type_, int index_) : coord(coord_), type(type_), index(index_) {
  
    }
    const bool operator<(const Event &other) const {
        return make_tuple(coord, type, index) < make_tuple(other.coord, other.type, other.index);
    }
};
  
void solve() {
    int n; cin >> n;
    vector<Segment> segs;
    vector<Event> events;
    for (int i = 0; i < n; i++) {
        int l, r; cin >> l >> r;
        segs.emplace_back(l, r);
        events.emplace_back(l, 1, i);
        events.emplace_back(r, -1, i);
    }
    sort(events.begin(), events.end());
    // auto cmp_in_set = [](const pair<Segment, int> &p1, const pair<Segment> &p2) {
    //     if (p1.first.l < p2.first.l) {
    //         return true;
    //     }
    //     if (p1.l > p2.l) {
    //         return false;
    //     }
    //     return p1.
    // };
    set<pair<int, int>> currently_opened; // l_coord and index
    vector<pair<Segment, int>> new_segs;
    for (const Event &e : events) {
        if (e.type == 1) {
            while (!currently_opened.empty()) {
                int idx = currently_opened.begin()->second;
                if (segs[idx].r < e.coord) {
                    new_segs.emplace_back(segs[idx], idx);
                    currently_opened.erase(currently_opened.begin());
                } else {
                    break;
                }
            }
            currently_opened.insert({e.coord, e.index});
        } else {
            int L = segs[e.index].l;
            while (!currently_opened.empty() && *currently_opened.begin() < make_pair(L, e.index)) {
                currently_opened.erase(currently_opened.begin());
            }
        }
    }
    for (auto [z, v] : currently_opened) {
        new_segs.emplace_back(segs[v], v);
    }
    // for (int i = 0; i < n; i++) {
    //     bool inner = false;
    //     for (int j = 0; j < n && !inner; j++) {
    //         if (i == j) continue;
    //         if (segs[i].contains(segs[j]) || (segs[i] == segs[j] && i < j)) {
    //             inner = true;
    //         }
    //     }
    //     if (!inner) {
    //         new_segs.emplace_back(segs[i], i);
    //     }
    // }
    sort(new_segs.begin(), new_segs.end(), [](const auto &s1, const auto &s2) {
        return s1.first.l < s2.first.l;
    });
    vector<int> max_independent;
    int r = 0;
    int ptr = 0;
    int k = new_segs.size();
    while (ptr < k) {
        while (ptr < k && new_segs[ptr].first.l <= r) {
            ptr++;
        }
        if (ptr != k) {
            r = new_segs[ptr].first.r;
            max_independent.push_back(new_segs[ptr].second);
        }
    }
    int m = max_independent.size();
    int R = segs[max_independent[m / 2 - 1]].r, L = segs[max_independent[m / 2]].l;
    int bad_first = 0, bad_second = 0;
    for (const Segment &seg : segs) {
        if (seg.l >= R) {
            bad_first++;
        }
        if (seg.r <= L) {
            bad_second++;
        }
    }
    vector<bool> is_independent(n);
    for (int i : max_independent) {
        is_independent[i] = true;
    }
    if (bad_first <= n / 2) {
        int left = (n - m) / 2;
        for (int i = 0; i < n; i++) {
            if (segs[i].l >= R) continue;
            if (is_independent[i]) {
                cout << i + 1 << ' ';
            } else if (left > 0) {
                cout << i + 1 << ' ';
                left--;
            }
        }
        assert(left == 0);
    } else {
        int left = (n - m) / 2;
        for (int i = 0; i < n; i++) {
            if (segs[i].r <= L) continue;
            if (is_independent[i]) {
                cout << i + 1 << ' ';
            } else if (left > 0) {
                cout << i + 1 << ' ';
                left--;
            }
        }
        assert(left == 0);
    }
    cout << endl;
}
  
int main() {
    int t; cin >> t;
    while (t--) {
        solve();
    }
}
