#include <iostream>
#include <vector>
#include <algorithm>
#include <numeric>

#define int int64_t

using namespace std;
using Graph = vector<vector<int>>;

int modmul(int x, int y, int m) {
    return (x * 1ll * y) % m;
}

struct Certificate {
    int value;
    int x, y, m;
    Certificate(int x_, int y_, int m_) : x(x_), y(y_), m(m_) {
        value = 0;
    }

    void add_vertex(int v, int z) {
        value ^= (modmul(x, v + 1, m) + modmul(y, modmul(z, z, m), m)) % m;
    }
};

void solve() {
    int n, q; cin >> n >> q;
    int x, y, m; cin >> x >> y >> m;
    Graph tree(n);
    for (int i = 0; i < n - 1; i++) {
        int v, u; cin >> v >> u; v--; u--;
        tree[v].push_back(u);
        tree[u].push_back(v);
    }
    vector<int> ls(n), rs(n);
    for (int i = 0; i < n; i++) {
        cin >> ls[i] >> rs[i];
    }
    vector<int64_t> vs(q);
    for (int64_t &i : vs) {
        cin >> i;
    }
    int64_t minV = 0;
    for (int i = 1; i < n; i++) {
        minV += ls[i];
    }
    minV = max(minV, ls[0]);
    int64_t maxV = 0;
    for (int i = 1; i < n; i++) {
        maxV += rs[i];
    }
    maxV = max(maxV, rs[0]);

    vector<int> order(q);
    iota(order.begin(), order.end(), 0);
    sort(order.begin(), order.end(), [&](int i, int j) {
        return vs[i] < vs[j];
    });
    vector<int> left(n);
    int64_t cur = 0;
    int ptr = 1;
    Certificate cur_certificate = Certificate(x, y, m);
    for (int i = 1; i < n; i++) {
        left[i] = rs[i] - ls[i];
        cur_certificate.add_vertex(i, ls[i]);
        cur += ls[i];
    }
    cur_certificate.add_vertex(0, ls[0]);
    vector<int> certificates(q, -1);
    vector<bool> from_zero(q);
    for (int i : order) {
        while (cur < vs[i] && ptr < n) {
            int64_t take = min(left[ptr], vs[i] - cur);
            cur_certificate.add_vertex(ptr, rs[ptr] - left[ptr]);
            left[ptr] -= take;
            cur_certificate.add_vertex(ptr, rs[ptr] - left[ptr]);
            if (left[ptr] == 0) ptr++;
            cur += take;
        }
        if (cur == vs[i]) {
            certificates[i] = cur_certificate.value;
        }
    }
    Certificate cum(x, y, m);
    for (int i = 1; i < n; i++) {
        cum.add_vertex(i, ls[i]);
    }
    for (int i : order) {
        if (vs[i] < minV) {
            certificates[i] = -1;
        }
        if (certificates[i] == -1 && minV <= vs[i] && vs[i] <= rs[0]) {
            Certificate cert = cum;
            cert.add_vertex(0, vs[i]);
            from_zero[i] = true;
            certificates[i] = cert.value;
        }
    }
    for (int i : certificates) {
        cout << i << ' ';
    }
    cout << endl;
    int check; cin >> check;
    while (check != 0) {
        check--;
        if (certificates[check] == -1) {
            cout << -1 << endl;
        } else if (from_zero[check]) {
            cout << vs[check] << ' ';
            for (int i = 1; i < n; i++) {
                cout << ls[i] << ' ';
            }
            cout << endl;
        } else {
            int64_t cur = 0;
            int ptr = 0;
            vector<int> left(n);
            for (int i = 1; i < n; i++) {
                left[i] = rs[i] - ls[i];
                cur += ls[i];
            }
            while (cur < vs[check] && ptr < n) {
                int64_t take = min(left[ptr], vs[check] - cur);
                left[ptr] -= take;
                ptr++;
                cur += take;
            }
            cout << ls[0] << ' ';
            for (int i = 1; i < n; i++) {
                cout << rs[i] - left[i] << ' ';
            }
            cout << endl;
        }
        cin >> check;
    }
}

signed main() {
    int t; cin >> t;
    while (t--) {
        solve();
    }
}
