#include <iostream>
#include <vector>
#include <cassert>

using namespace std;
using Graph = vector<vector<int>>;

struct Segment {
    int64_t l, r;
    explicit Segment() = default;
    Segment(int64_t l_, int64_t r_) : l(l_), r(r_) {

    }
    const Segment operator+(const Segment &other) const {
        return Segment(l + other.l, r + other.r);
    }

    const Segment operator|(const Segment &other) const {
        assert(!(other.l > r || l > other.r));
        return Segment(min(l, other.l), max(r, other.r));
    };
};

void calc_dp(const Graph &tree, int v, int p, vector<Segment> &values, vector<Segment> &dp_take, vector<Segment> &dp_no_take) {
    dp_take[v] = values[v];
    for (int u : tree[v]) {
        if (u != p) {
            calc_dp(tree, u, v, values, dp_take, dp_no_take);
            dp_no_take[v] = dp_no_take[v] + (dp_take[u] | dp_no_take[u]);
            dp_take[v] = dp_take[v] + dp_no_take[u];
        }
    }
}

int modmul(int x, int y, int m) {
    return (x * 1ll * y) % m;
}

void solve() {
    int n, q; cin >> n >> q;
    int x, y, m; cin >> x >> y >> m;
    Graph tree(n);
    for (int i = 0; i < n - 1; i++) {
        int v, u; cin >> v >> u; v--; u--;
        tree[v].push_back(u);
        tree[u].push_back(v);
    }
    vector<Segment> values(n);
    for (int i = 0; i < n; i++) {
        int l, r; cin >> l >> r;
        values[i] = Segment(l, r);
    }
    vector<int64_t> vs(q);
    for (int64_t &i : vs) {
        cin >> i;
    }
    vector<Segment> dp_take(n), dp_no_take(n);
    calc_dp(tree, 0, -1, values, dp_take, dp_no_take);
    Segment z = dp_take[0] | dp_no_take[0];
    for (int64_t v : vs) {
        cout << (z.l <= v && v <= z.r ? 0 : -1) << endl;
    }
    int check; cin >> check;
    assert(check == 0);
}

int main() {
    int t; cin >> t;
    while (t--) {
        solve();
    }
}
