#include <iostream>
#include <cmath>
#include <algorithm>
#include <vector>
#include <array>

using namespace std;

#define int long long
#define sz(x) (int) ((x).size())
#define all(x) (x).begin(), (x).end()

const int inf = 1e18;

//struct Tree {
//  vector<int> tree;
//  int s;
//
//  Tree(int n) {
//    s = 1;
//    while (s < n) s *= 2;
//    tree.assign(2 * s + 1, -inf);
//  }
//
//  int get(int l, int r, int x, int lx, int rx) {
//    if (lx >= r || rx <= l) {
//      return -inf;
//    }
//    if (lx >= l && rx <= r) {
//      return tree[x];
//    }
//    int m = (lx + rx) / 2;
//    return max(get(l, r, 2 * x + 1, lx, m), get(l, r, 2 * x + 2, m, rx));
//  }
//};

struct Fenwick {
  int n;
  bool rev;
  vector<int> t;

  Fenwick() {}
  Fenwick(int n, bool rev): n(n), rev(rev), t(n + 1) {}

  void upd(int i, int val) {
    if (rev) {
      i = n - i;
    } else {
      i += 1;
    }
    for (; i <= n; i += i & -i) {
      t[i] = max(t[i], val);
    }
  }

  int get(int r) {
    int res = -inf;
    if (rev) {
      r = n - r;
    } else {
      r += 1;
    }
    for (; r > 0; r -= r & -r) {
      res = max(res, t[r]);
    }

    return res;
  }
};

void solve() {
  int n;
  cin >> n;
  vector<int> a(n), pos(n + 2, -1);
  for (int i = 0; i < n; i++) {
    cin >> a[i];
    pos[a[i]] = i;
  }

  vector<Fenwick> ft1(n + 2), ft2(n + 2);
  vector dp(n + 2, vector<int> (n + 2, -inf));

  for (int i = 0; i < n + 2; i++) {
    ft1[i] = Fenwick(n + 2, true);
    ft2[i] = Fenwick(n + 2, false);
  }

  auto upd = [&] (int val1, int val2, int val) {
    if (val > dp[val1][val2]) {
      dp[val1][val2] = val;
      ft1[val1].upd(val2, val);
      ft2[val2].upd(val1, val);
    }
  };

  upd(a[0], n + 1, 1);
  upd(0, a[0], 1);
  for (int i = 1; i < n; i++) {
    { // dp[a[i]][val2]
      for (int val2 = n + 1; val2 >= 1; val2--) {
        upd(a[i], val2, ft2[val2].get(a[i] - 1) + 1);
      }
    }
    { // dp[val1][a[i]]
      for (int val1 = 0; val1 <= n; val1++) {
        upd(val1, a[i], ft1[val1].get(a[i] + 1) + 1);
      }
    }
  }
//  for (int val1 = 0; val1 <= n; val1++) {
//    for (int val2 = n + 1; val2 >= 1; val2--) {
//      int id = max(pos[val1], pos[val2]);
//      for (int j = id + 1; j < n; j++) {
//        if (a[j] > val1) {
//          dp[a[j]][val2] = max(dp[a[j]][val2], dp[val1][val2] + 1);
//        }
//        if (a[j] < val2) {
//          dp[val1][a[j]] = max(dp[val1][a[j]], dp[val1][val2] + 1);
//        }
//        if (a[j] > val1 && a[j] < val2) {
//          break;
//        }
//      }
//    }
//  }

//  vector dp(n, vector (n + 2, vector<int> (n + 2, -inf)));
//  dp[0][a[0]][n + 1] = 1;
//  dp[0][0][a[0]] = 1;
//  for (int i = 0; i + 1 < n; i++) {
//    for (int val1 = 0; val1 <= n; val1++) {
//      for (int val2 = 1; val2 <= n + 1; val2++) {
//        if (a[i + 1] > val1) {
//          dp[i + 1][a[i + 1]][val2] = max(dp[i + 1][a[i + 1]][val2], dp[i][val1][val2] + 1);
//        } else {
//          dp[i + 1][val1][val2] = max(dp[i + 1][val1][val2], dp[i][val1][val2]);
//        }
//        if (a[i + 1] < val2) {
//          dp[i + 1][val1][a[i + 1]] = max(dp[i + 1][val1][a[i + 1]], dp[i][val1][val2] + 1);
//        } else {
//          dp[i + 1][val1][val2] = max(dp[i + 1][val1][val2], dp[i][val1][val2]);
//        }
//      }
//    }
//  }

  int ans = -inf;
  for (int val1 = 0; val1 <= n + 1; val1++) {
    for (int val2 = 0; val2 <= n + 1; val2++) {
      ans = max(ans, dp[val1][val2]);
    }
  }

  cout << ans - 1 << '\n';
}

int32_t main() {
#ifdef LOCAL
  freopen("input.txt", "r", stdin);
#endif
  ios_base::sync_with_stdio(false);
  cin.tie(0);
  int tc;
  cin >> tc;
  while (tc --> 0) solve();
  return 0;
}