#include <iostream>
#include <vector>
#include <algorithm>

using namespace std;


class SegmentTree {
private:
	struct Node {
		int mx;
		int idx;
		Node() {}
	};
	vector<Node> tree;
	int n;
	void upd(int i, int l, int r, int q, int x, int idx) {
		if (q < l || q >= r)
			return;
		if (r - l == 1) {
			if (tree[i].mx < x) {
				tree[i].mx = x;
				tree[i].idx = idx;
			}
			return;
		}
		int m = (l + r) / 2;
		upd(i * 2, l, m, q, x, idx);
		upd(i * 2 + 1, m, r, q, x, idx);
		if (tree[i].mx < tree[i * 2].mx) {
			tree[i].mx = tree[i * 2].mx;
			tree[i].idx = tree[i * 2].idx;
		}
		if (tree[i].mx < tree[i * 2 + 1].mx) {
			tree[i].mx = tree[i * 2 + 1].mx;
			tree[i].idx = tree[i * 2 + 1].idx;
		}
	}

	pair<int, int> get(int i, int l, int r, int ql, int qr) {
		if (qr <= l || r <= ql)
			return { -1, -1 };
		if (ql <= l && r <= qr)
			return { tree[i].mx, tree[i].idx };
		int m = (l + r) / 2;
		pair<int, int> f1 = get(i * 2, l, m, ql, qr);
		pair<int, int> f2 = get(i * 2 + 1, m, r, ql, qr);
		if (f1.first > f2.first)
			return f1;
		return f2;
	}

public:
	SegmentTree(int n_) : n(1) {
		while (n < n_)
			n *= 2;
		tree.resize(n * 2);
	}
	void upd(int q, int x, int idx) {
		upd(1, 0, n, q, x, idx);
	}
	pair<int, int> get(int ql, int qr) {
		return get(1, 0, n, ql, qr);
	}
};

int nvp(vector<int>& a, SegmentTree& t, vector<int>& dp, vector<int>& p) {
	int n = a.size();
	int mx = 0;
	for (int i = 0; i < n; ++i) {
		pair<int, int> res = t.get(0, a[i]);
		dp[i] = max(0, res.first) + 1;
		p[i] = res.second;
		t.upd(a[i], dp[i], i);
		mx = max(mx, dp[i]);
	}
	return mx;
}

void solve() {
	int n;
	cin >> n;
	vector<int> a(n);
	for (int i = 0; i < n; ++i) {
		cin >> a[i];
	}
	SegmentTree t1(n + 1);
	vector<int> dp(n), p(n);
	int x = nvp(a, t1, dp, p);
	cout << x + 1 << "\n";
}

int main() {
	ios_base::sync_with_stdio(false);
	cin.tie(0);
	cout.tie(0);

	int t;
	cin >> t;
	while (t--) {
		solve();
	}
}