#include <iostream>
#include <bits/stdc++.h>

using namespace std;

using ll = long long;
using ld = long double;

ll INF = 1e18;
ll MOD = 1e9 + 7;
ld EPS = 1e-9;

struct DSU {
    vector<ll> p, sz;

    explicit DSU(ll n) {
        p.assign(n, 0);
        for (ll i = 0; i < n; i++) p[i] = i;
        sz.assign(n, 1);
    }

    ll get(ll v) {
        if (p[v] == v) return v;
        return p[v] = get(p[v]);
    }

    void merge(ll a, ll b) {
        a = get(a), b = get(b);
        if (a == b) return;

        if (sz[a] < sz[b]) swap(a, b);

        sz[a] += sz[b];
        p[b] = a;
    }
};

struct SegmentTree {
    struct Node {
        ll x, ind;
    };

    Node NEUTRAL = {0, 0};
    ll n;

    vector<Node> p;

    explicit SegmentTree(ll n): n(n) {
        p.assign(4 * n, NEUTRAL);
        build(0, 0, n);
    }

    Node merge(Node p1, Node p2) {
        if (p2.x >= p1.x) return p2;
        return p1;
    }

    void build(ll i, ll l, ll r) {
        if (l + 1 == r) {
            p[i] = {0, l};
        } else {
            ll m = (l + r) / 2;
            build(2 * i + 1, l, m);
            build(2 * i + 2, m, r);

            p[i] = merge(p[2 * i + 1], p[2 * i + 2]);
        }
    }

    Node _get(ll i, ll l, ll r, ll q_l, ll q_r) {
        if (r <= q_l || q_r <= l) return NEUTRAL;
        if (q_l <= l && r <= q_r) return p[i];

        ll m = (l + r) / 2;
        return merge(_get(2 * i + 1, l, m, q_l, q_r), _get(2 * i + 2, m, r, q_l, q_r));
    }

     void _set(ll i, ll l, ll r, ll q_i, ll q_x) {
        if (l + 1 == r) {
            p[i] = {q_x, l};
        } else {
            ll m = (l + r) / 2;
            if (q_i < m)
                _set(2 * i + 1, l, m, q_i, q_x);
            else
                _set(2 * i + 2, m, r, q_i, q_x);

            p[i] = merge(p[2 * i + 1], p[2 * i + 2]);
        }
    }

    Node get(ll l, ll r) {
        return _get(0, 0, n, l, r);
    }

    void set(ll i, ll x) {
        _set(0, 0, n, i, x);
    }
};

ll mex(vector<ll> a) {
    if (a[0] != 0) return 0;
    for (ll i = 1; i < a.size(); i++) {
        if (a[i] != i) return a[i-1] + 1;
    }

    return a.back() + 1;
}

map<vector<ll>, vector<vector<ll>>> g;

int main() {
#ifdef LOCAL
    freopen("inp.txt", "r", stdin);
    freopen("out.txt", "w", stdout);

    clock_t timer = clock();
#else
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    cout.tie(nullptr);
    cout.precision(64);
    cout << fixed;
#endif

    cin >> MOD;

    ll t;
    cin >> t;

    while (t--) {
        g.clear();
        ll k, n, p;
        cin >> k >> n >> p;
        vector<ll> perm(1 << k);
        std::iota(perm.begin(), perm.end(), 0);

        set<vector<ll>> u;

        do {
            vector<ll> z = perm;
            z.resize(n);
            std::sort(z.begin(), z.end());
            if (z[0] != 0) continue;
            if (u.find(z) != u.end()) continue;
            u.insert(z);

            auto np = z;
            sort(np.begin(), np.end());
            ll mx = mex(np);
            for (ll &i : np) i ^= (mx - 1);
            sort(np.begin(), np.end());

            g[z].push_back(np);
        } while (std::next_permutation(perm.begin(), perm.end()));

        ll ans = 0;
        for (auto &w : g) {
            auto v = w.first;
            bool ok = true;
            while (true) {
                if (v == g[v][0]) {
                    break;
                } else if (g[v][0] == w.first) {
                    ok = false;
                    break;
                }

                v = g[v][0];
            }

            if (!ok) continue;

            if (mex(v) == p) ans++;
        }

        cout << ans << "\n";
    }

#ifdef LOCAL
    cout << "\nExecution time: " << (ld)(clock() - timer) / CLOCKS_PER_SEC;
#endif
}